@@ -6,7 +6,6 @@
 #' @export
 #' @inheritParams genetic_algorithm
 #' @param result The resulting matrix of the function \code{\link{genetic_algorithm}}
-#' or \code{\link{windfarmGA}}
 #' @param best Which best individuals should be the starting conditions for a
 #'   random search. The default is 1.
 #' @param n The number of random searches to be performed. Default is 20.
@@ -25,8 +24,8 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
   ## TODO - Performance and structure ---
   ## Data Config ############################
   # Order the resulting layouts with highest Energy output
-  resldat <- do.call("rbind", result[,"bestPaEn"])
-  maxDist <- as.numeric(result[,"inputData"][[1]]['Rotorradius',]) * max_dist
+  resldat <- do.call("rbind", result[, "bestPaEn"])
+  maxDist <- as.numeric(result[, "inputData"][[1]]["Rotorradius", ]) * max_dist
 
   ## Remove duplicated layouts based on x, y energy / efficiency
   resldat <- resldat[!duplicated(resldat[, 1:4]), ]
@@ -40,51 +39,53 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
 
   ## Process Data ########
   ## Remove duplicated "Runs", assign do resldat and sort by Energy
-  resldat <- as.data.frame(resldat[!duplicated(resldat[, 'Run']),, drop=FALSE])
+  resldat <- as.data.frame(resldat[!duplicated(resldat[, "Run"]), , drop = FALSE])
   resldat$GARun <- 1:nrow(resldat)
   ## Sort by EnergyOverall
-  resldat <- resldat[order(resldat[, 4], decreasing = TRUE),]
+  resldat <- resldat[order(resldat[, 4], decreasing = TRUE), ]
 
   ## Get the GA-runs of the best layouts
   if (best > nrow(resldat)) {
-    message(paste0("Only ",nrow(resldat), " unique layouts found. Set 'best' to ",
-                   nrow(resldat)))
+    message(paste0(
+      "Only ", nrow(resldat), " unique layouts found. Set 'best' to ",
+      nrow(resldat)
+    ))
     best <- nrow(resldat)
   }
   bestGARunIn <- resldat$GARun[1:best]
 
-  resolu <- max(as.numeric(result[bestGARunIn[1],]$inputData["Resolution",][1]))
-  rotRad <- max(as.numeric(result[bestGARunIn[1],]$inputData["Rotorradius",][1]))
-  winddata <- result[bestGARunIn[1],]$inputWind
+  resolu <- max(as.numeric(result[bestGARunIn[1], ]$inputData["Resolution", ][1]))
+  rotRad <- max(as.numeric(result[bestGARunIn[1], ]$inputData["Rotorradius", ][1]))
+  winddata <- result[bestGARunIn[1], ]$inputWind
   ## Get max factor for alteration of coordination
   maxFac <- rotRad * (resolu / (rotRad * 2))
 
   ## Grid the Polygon ############
   Polygon1 <- isSpatial(shape = Polygon1)
-  GridMethod <- result[1,"inputData"][[1]]["Grid Method",][[1]]
+  GridMethod <- result[1, "inputData"][[1]]["Grid Method", ][[1]]
   GridMethod <- toupper(GridMethod)
-  if (GridMethod != "HEXAGON" & GridMethod != "H") {
+  if (GridMethod != "HEXAGON" && GridMethod != "H") {
     # Calculate a Grid and an indexed data.frame with coordinates and grid cell Ids.
-    propu  <- as.numeric(result[bestGARunIn[1],]$inputData["Percentage of Polygon",][1])
+    propu <- as.numeric(result[bestGARunIn[1], ]$inputData["Percentage of Polygon", ][1])
     Grid <- grid_area(shape = Polygon1, size = resolu, prop = propu)
   } else {
     # Calculate a Grid with hexagonal grid cells
     Grid <- hexa_area(Polygon1, resolu)
   }
-  
+
   ## Windata Formatting ###################
   winddata <- windata_format(winddata)
   probabDir <- winddata[[2]]
   winddata <- winddata[[1]]
-  
+
   ## Init arguments ########
   ## Get reference / turbine height and rotor radius of 1 individual.
   # TODO - if 3D-wake possible, turbine height must be evaluated in the loop
   ## If different rotor radii, it must also go in the loop
   ref_height <- as.numeric(result[1, ]$inputData[12, ])
   rotor_height <- as.numeric(result[1, ]$inputData[13, ])
-  rotor_radius <- as.numeric(result[1,]$inputData[1,])
-  
+  rotor_radius <- as.numeric(result[1, ]$inputData[1, ])
+
   max_angle <- getOption("windfarmGA.max_angle")
   max_dist <- getOption("windfarmGA.max_distance")
 
@@ -98,25 +99,29 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
     coordLay <- layout_start[, 1:2]
 
     if (Plot) {
-      raster::plot(Grid[[2]])
+      plot(Grid[[2]])
       points(coordLay, pch = 15, col = "black")
-      
-      legend(x = "bottom", 
-              legend = c("Starting Location", "Randomly generated Location", 
-                       "Suitable Location", "Relocated due to Turbine Collision"),
-              col = c("black", "blue","green", "red"), lwd = 1, lty = c(0, 0), 
-              pch = c(15, 3, 1, 20))
+
+      legend(
+        x = "bottom",
+        legend = c(
+          "Starting Location", "Randomly generated Location",
+          "Suitable Location", "Relocated due to Turbine Collision"
+        ),
+        col = c("black", "blue", "green", "red"), lwd = 1, lty = c(0, 0),
+        pch = c(15, 3, 1, 20)
+      )
     }
 
     ## Run n random searches on windfarm[o]
     RandResult <- vector(mode = "list", length = n)
     for (i in 1:n) {
-      coordLayTmp <- vector(mode = "list", length = length(coordLay[,1]))
+      coordLayTmp <- vector(mode = "list", length = length(coordLay[, 1]))
       ## For every turbine, alter x/y coordinates randomly
-      for (j in 1:length(coordLay[,1])) {
+      for (j in 1:length(coordLay[, 1])) {
         maxAlterX <- runif(1, min = -maxFac, max = maxFac)
         maxAlterY <- runif(1, min = -maxFac, max = maxFac)
-        cordNew <- coordLay[j,]
+        cordNew <- coordLay[j, ]
         cordNew[1] <- cordNew[1] + maxAlterX
         cordNew[2] <- cordNew[2] + maxAlterY
         if (Plot) {
@@ -127,12 +132,12 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
       coordsj <- do.call("rbind", coordLayTmp)
 
       ## Check if turbines are not colliding #####################
-      pointsDistBl <- st_as_sf(data.frame(coordsj), coords = c("X","Y"))
+      pointsDistBl <- st_as_sf(data.frame(coordsj), coords = c("X", "Y"))
       pointsDist <- st_distance(pointsDistBl)
       distMin <- pointsDist[which(pointsDist < maxDist & pointsDist != 0)]
 
       while (length(distMin) > 0) {
-        pointsDistBl <- st_as_sf(data.frame(coordsj), coords = c("X","Y"))
+        pointsDistBl <- st_as_sf(data.frame(coordsj), coords = c("X", "Y"))
         pointsDist <- st_distance(pointsDistBl)
         distMin <- pointsDist[which(pointsDist < maxDist & pointsDist != 0)]
         if (length(distMin) != 0) {
@@ -143,10 +148,11 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
           distMin <- round(distMin, 2)
           distMin <- distMin[duplicated(distMin)]
 
-          ColRowMin <- which(pointsDist == distMin, 
-                             useNames = TRUE, arr.ind = TRUE)
+          ColRowMin <- which(pointsDist == distMin,
+            useNames = TRUE, arr.ind = TRUE
+          )
 
-          CoordsWrongOrigin <- coordLay[ColRowMin[1, 2],]
+          CoordsWrongOrigin <- coordLay[ColRowMin[1, 2], ]
 
           maxAlterX <- runif(1, min = -maxFac, max = maxFac)
           maxAlterY <- runif(1, min = -maxFac, max = maxFac)
@@ -155,11 +161,13 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
           cordNew[2] <- cordNew[2] + maxAlterY
 
           if (Plot) {
-            points(x = coordsj[ColRowMin[1, 2],1],
-                   y = coordsj[ColRowMin[1, 2],2],
-                   col = "red", cex = 1.2, pch = 20)
+            points(
+              x = coordsj[ColRowMin[1, 2], 1],
+              y = coordsj[ColRowMin[1, 2], 2],
+              col = "red", cex = 1.2, pch = 20
+            )
           }
-          coordsj[ColRowMin[1, 2],] <- cordNew
+          coordsj[ColRowMin[1, 2], ] <- cordNew
         }
       }
       if (Plot) {
@@ -169,55 +177,70 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
 
       ## Arrange random points to input for calculate_energy
       coordsj <- cbind(coordsj,
-                       "ID" = 1,
-                       "bin" = 1)
+        "ID" = 1,
+        "bin" = 1
+      )
       coordsj <- coordsj[, c("ID", "X", "Y", "bin")]
 
       # Calculate energy and save in list with length n ################
-      resCalcen <- calculate_energy(sel = coordsj,
-                               referenceHeight = ref_height,
-                               RotorHeight = rotor_height,
-                               SurfaceRoughness = 0.3,
-                               wnkl = max_angle, distanz = max_dist,
-                               dirSpeed = winddata,
-                               RotorR = rotor_radius,
-                               polygon1 = Polygon1, topograp = FALSE,
-                               srtm_crop = NULL, cclRaster = NULL, 
-                               weibull = FALSE)
+      resCalcen <- calculate_energy(
+        sel = coordsj,
+        referenceHeight = ref_height,
+        RotorHeight = rotor_height,
+        SurfaceRoughness = 0.3,
+        wnkl = max_angle, distanz = max_dist,
+        dirSpeed = winddata,
+        RotorR = rotor_radius,
+        polygon1 = Polygon1, topograp = FALSE,
+        srtm_crop = NULL, cclRaster = NULL,
+        weibull = FALSE
+      )
 
       ## Process Result ###################
       ## TODO - optimize all next lines (calculate_energy has already beeter method)
       ee <- lapply(resCalcen, function(x) {
-        subset.matrix(x, subset = !duplicated(x[,'Punkt_id']),
-                      select = c('Bx','By','Windrichtung','RotorR','TotAbschProz','V_New',
-                                 'Rect_ID','Energy_Output_Red', 'Energy_Output_Voll',
-                                 'Parkwirkungsgrad'))
+        subset.matrix(x,
+          subset = !duplicated(x[, "Punkt_id"]),
+          select = c(
+            "Bx", "By", "Windrichtung", "RotorR", "TotAbschProz", "V_New",
+            "Rect_ID", "Energy_Output_Red", "Energy_Output_Voll",
+            "Parkwirkungsgrad"
+          )
+        )
       })
 
       # get Energy Output and Efficiency rate for every wind direction
-      enOut <- lapply(ee, function(x){
-        subset.matrix(x, 
-                      subset = c(TRUE, rep(FALSE, length(ee[[1]][, 1]) - 1)),
-                      select = c("Windrichtung", "Energy_Output_Red", 
-                                 "Parkwirkungsgrad"))})
+      enOut <- lapply(ee, function(x) {
+        subset.matrix(x,
+          subset = c(TRUE, rep(FALSE, length(ee[[1]][, 1]) - 1)),
+          select = c(
+            "Windrichtung", "Energy_Output_Red",
+            "Parkwirkungsgrad"
+          )
+        )
+      })
       enOut <- do.call("rbind", enOut)
 
       # Add the Probability of every direction
       # Calculate the relative Energy outputs relative to wind direction probabilities
       enOut <- cbind(enOut, "probabDir" = probabDir)
-      enOut <- cbind(enOut, "Eneralldire" = 
-                       enOut[, "Energy_Output_Red"] * (enOut[, "probabDir"] / 100))
+      enOut <- cbind(enOut,
+        "Eneralldire" =
+          enOut[, "Energy_Output_Red"] * (enOut[, "probabDir"] / 100)
+      )
 
       # Calculate the sum of the relative Energy outputs
       enOut <- cbind(enOut, "EnergyOverall" = sum(enOut[, "Eneralldire"]))
 
-      # Calculate the sum of the relative Efficiency rates respective to 
+      # Calculate the sum of the relative Efficiency rates respective to
       # the probability of the wind direction
-      enOut <- cbind(enOut, "Efficalldire" = 
-                       sum(enOut[, "Parkwirkungsgrad"] * (enOut[, "probabDir"] / 100)))
+      enOut <- cbind(enOut,
+        "Efficalldire" =
+          sum(enOut[, "Parkwirkungsgrad"] * (enOut[, "probabDir"] / 100))
+      )
 
       # Get the total Wake Effect of every Turbine for all Wind directions
-      total_wake <- lapply(ee, function(x){
+      total_wake <- lapply(ee, function(x) {
         x[, "TotAbschProz"]
       })
       total_wake <- do.call("cbind", total_wake)
@@ -226,24 +249,26 @@ random_search <- function(result, Polygon1, n = 20, best = 1, Plot = FALSE, max_
       # Get the original X / Y - Coordinates of the selected individual
       xundyOrig <- coordsj[, 2:3]
 
-      # Add the Efficieny and the Energy Output of all wind directions and add the total 
+      # Add the Efficieny and the Energy Output of all wind directions and add the total
       # Wake Effect of every Point Location
       # Include the Run of the genertion to the data frame
       xundyOrig <- cbind(xundyOrig,
-                         "EfficAllDir" = enOut[1, "Efficalldire"],
-                         "EnergyOverall" = enOut[1, "EnergyOverall"],
-                         "AbschGesamt" = total_wake,
-                         "Run" = i)
+        "EfficAllDir" = enOut[1, "Efficalldire"],
+        "EnergyOverall" = enOut[1, "EnergyOverall"],
+        "AbschGesamt" = total_wake,
+        "Run" = i
+      )
 
       # Get the Rotor Radius and the Rect_IDs of the park configuration
-      ## TODO - rotor radius is already saved outisde the loop and Rect_ID is just dummy 
-      dt <-  ee[[1]]
+      ## TODO - rotor radius is already saved outisde the loop and Rect_ID is just dummy
+      dt <- ee[[1]]
       dt <- subset.matrix(dt, select = c("RotorR", "Rect_ID"))
 
       # Bind the Efficiency,Energy,WakeEffect,Run to the Radius and Rect_IDs
       dt <- cbind(xundyOrig,
-                  dt,
-                  "bestGARun" = bestGARun)
+        dt,
+        "bestGARun" = bestGARun
+      )
 
       RandResult[[i]] <- dt
     }
@@ -271,90 +296,97 @@ random_search_single <- function(result, Polygon1, n = 20, Plot = FALSE, max_dis
   ## TODO - Performance and structure ---
   ## Data Config ############################
   # Order the resulting layouts with highest Energy output
-  resldat <- do.call("rbind", result[,"bestPaEn"])
-  maxDist <- as.numeric(result[,"inputData"][[1]]['Rotorradius',]) * max_dist
-  
+  resldat <- do.call("rbind", result[, "bestPaEn"])
+  maxDist <- as.numeric(result[, "inputData"][[1]]["Rotorradius", ]) * max_dist
+
   if (Plot) {
     plot.new()
     opar <- par(no.readonly = TRUE)
     on.exit(par(opar))
     par(mfrow = c(1, 1))
   }
-  
+
   ## Process Data ########
   ## Remove duplicated "Runs", assign do resldat and sort by Energy
-  resldat <- as.data.frame(resldat[!duplicated(resldat[,'Run']),, drop=FALSE])
+  resldat <- as.data.frame(resldat[!duplicated(resldat[, "Run"]), , drop = FALSE])
   resldat$GARun <- 1:nrow(resldat)
   ## Sort by EnergyOverall
-  resldat <- resldat[order(resldat[, 4], decreasing = TRUE),]
-  
+  resldat <- resldat[order(resldat[, 4], decreasing = TRUE), ]
+
   ## Get the GA-run of the best layout
   bestGARun <- resldat$GARun[1]
-  
-  resolu <- as.numeric(result[bestGARun,]$inputData["Resolution",][1])
-  rotRad <- as.numeric(result[bestGARun,]$inputData["Rotorradius",][1])
-  winddata <- result[bestGARun,]$inputWind
+
+  resolu <- as.numeric(result[bestGARun, ]$inputData["Resolution", ][1])
+  rotRad <- as.numeric(result[bestGARun, ]$inputData["Rotorradius", ][1])
+  winddata <- result[bestGARun, ]$inputWind
   ## Get max factor for alteration of coordination
   maxFac <- rotRad * (resolu / (rotRad * 2))
-  
+
   ## Grid the Polygon ############
   Polygon1 <- isSpatial(shape = Polygon1)
-  GridMethod <- result[1,"inputData"][[1]]["Grid Method",][[1]]
+  GridMethod <- result[1, "inputData"][[1]]["Grid Method", ][[1]]
   GridMethod <- toupper(GridMethod)
-  if (GridMethod != "HEXAGON" & GridMethod != "H") {
+  if (GridMethod != "HEXAGON" && GridMethod != "H") {
     # Calculate a Grid and indexed coordinates of all grid cell centers
-    propu  <- as.numeric(result[bestGARun,]$inputData["Percentage of Polygon",][1])
+    propu <- as.numeric(result[bestGARun, ]$inputData["Percentage of Polygon", ][1])
     Grid <- grid_area(shape = Polygon1, size = resolu, prop = propu)
   } else {
     # Calculate a Grid with hexagonal grid cells
     Grid <- hexa_area(Polygon1, resolu)
   }
-  
+
   ## Windata Formatting ###################
   winddata <- windata_format(winddata)
   probabDir <- winddata[[2]]
   winddata <- winddata[[1]]
-  
+
   ## Init arguments ########
   ## Get reference / turbine height and rotor radius of 1 individual.
   # TODO - if 3D-wake possible, turbine height must be evaluated in the loop
   ## If different rotor radii, it must also go in the loop
   ref_height <- as.numeric(result[bestGARun, ]$inputData[12, ])
   rotor_height <- as.numeric(result[bestGARun, ]$inputData[13, ])
-  rotor_radius <- as.numeric(result[bestGARun,]$inputData[1,])
-  
+  rotor_radius <- as.numeric(result[bestGARun, ]$inputData[1, ])
+
   max_angle <- getOption("windfarmGA.max_angle")
   max_dist <- getOption("windfarmGA.max_distance")
-  
+
   ## Turbine Indexing by user input (Must be plotted) ################
   ## Get the starting layout of windfarm[o]
-  layout_start <- result[bestGARun,]$bestPaEn
-  raster::plot(Grid[[2]])
+  layout_start <- result[bestGARun, ]$bestPaEn
+  plot(Grid[[2]])
   points(x = layout_start[, "X"], y = layout_start[, "Y"], pch = 15)
-  calibrate::textxy(X = layout_start[, "X"], Y = layout_start[, "Y"], 
-                    labs = layout_start[, "Rect_ID"], cex = 1.5, offset = 0.75)
+  calibrate::textxy(
+    X = layout_start[, "X"], Y = layout_start[, "Y"],
+    labs = layout_start[, "Rect_ID"], cex = 1.5, offset = 0.75
+  )
   turbInx <- ""
-  while (!turbInx %in% layout_start[,'Rect_ID']) {
-    cat("Enter the turbine number that you want to optimize.")
-    # turbInx <- readline(prompt = "Please enter the corresponding number: ")
-    cat("Please enter the corresponding number:\n")
+  while (!turbInx %in% layout_start[, "Rect_ID"]) {
+    message("Enter the turbine number that you want to optimize.")
+    message("Please enter the corresponding number:\n")
     turbInx <- readLines(n = 1, con = getOption("windfarmGA.connection"))
   }
-  turbInx <- which(layout_start[, 'Rect_ID'] == as.numeric(turbInx))
+  turbInx <- which(layout_start[, "Rect_ID"] == as.numeric(turbInx))
   coordLay <- layout_start[, 1:2]
   if (Plot) {
-    raster::plot(Grid[[2]])
+    plot(Grid[[2]])
     points(coordLay, pch = 15, col = "black")
     points(coordLay[as.numeric(turbInx), ][1],
-           coordLay[as.numeric(turbInx), ][2], pch = 15, col = "purple")
-    
-    legend( x = "bottom", 
-            legend = c("Starting Location", "Selected Turbine", "Randomly generated Location",
-                       "Suitable Location", "Relocated due to Turbine Collision"),
-            col = c("black", "purple", "blue", "green", "red"), lwd = 1, lty = c(0, 0),
-            pch = c(15, 15, 3, 20, 20))
+      coordLay[as.numeric(turbInx), ][2],
+      pch = 15, col = "purple"
+    )
+
+    legend(
+      x = "bottom",
+      legend = c(
+        "Starting Location", "Selected Turbine", "Randomly generated Location",
+        "Suitable Location", "Relocated due to Turbine Collision"
+      ),
+      col = c("black", "purple", "blue", "green", "red"), lwd = 1, lty = c(0, 0),
+      pch = c(15, 15, 3, 20, 20)
+    )
   }
-  
+
   ## Run Random Search  ################
   RandResult <- vector(mode = "list", length = n)
   for (i in 1:n) {
@@ -363,35 +395,35 @@ random_search_single <- function(result, Polygon1, n = 20, Plot = FALSE, max_dis
     ## Get random steps for x/y and add to coords of "problematic" turbine
     maxAlterX <- runif(1, min = -maxFac, max = maxFac)
     maxAlterY <- runif(1, min = -maxFac, max = maxFac)
-    cordNew <- coordLay[as.numeric(turbInx),]
+    cordNew <- coordLay[as.numeric(turbInx), ]
     cordNew[1] <- cordNew[1] + maxAlterX
     cordNew[2] <- cordNew[2] + maxAlterY
     if (Plot) {
       points(cordNew[1], cordNew[2], col = "blue", pch = 3)
     }
-    
+
     ## Assign new coordinates to "problematic" turbine
-    coordLayRnd[as.numeric(turbInx),] <- cordNew 
-    
+    coordLayRnd[as.numeric(turbInx), ] <- cordNew
+
     ## Check if turbines are colliding #####################
-    pointsDistBl <- st_as_sf(data.frame(coordLayRnd), coords = c("X","Y"))
+    pointsDistBl <- st_as_sf(data.frame(coordLayRnd), coords = c("X", "Y"))
     pointsDist <- st_distance(pointsDistBl)
     distMin <- pointsDist[which(pointsDist < maxDist & pointsDist != 0)]
-    
-    
+
+
     while (length(distMin) > 0) {
-      pointsDistBl <- st_as_sf(data.frame(coordLayRnd), coords = c("X","Y"))
+      pointsDistBl <- st_as_sf(data.frame(coordLayRnd), coords = c("X", "Y"))
       pointsDist <- st_distance(pointsDistBl)
       distMin <- pointsDist[which(pointsDist < maxDist & pointsDist != 0)]
       if (length(distMin) != 0) {
         pointsDist <- data.frame(pointsDist)
         colnames(pointsDist) <- 1:length(pointsDist)
-        
+
         ## TODO - docs. whats going on here and why
-        pointsDist <- round(pointsDist, 2) 
+        pointsDist <- round(pointsDist, 2)
         distMin <- round(distMin, 2)
         distMin <- distMin[duplicated(distMin)]
-        
+
         ## Copy the original layout (really need that? AGAIN ?)
         cordNew <- coordLay[as.numeric(turbInx), ]
         ## Get random steps for x/y and add to coords of "problematic" turbine
@@ -400,95 +432,108 @@ random_search_single <- function(result, Polygon1, n = 20, Plot = FALSE, max_dis
         ## Try new random steps
         cordNew[1] <- cordNew[1] + maxAlterX
         cordNew[2] <- cordNew[2] + maxAlterY
-        
+
         if (Plot) {
-          points(x = cordNew[1],
-                 y = cordNew[2],
-                 col = "red", pch = 20)
+          points(
+            x = cordNew[1],
+            y = cordNew[2],
+            col = "red", pch = 20
+          )
         }
-        
+
         ## Assign new random steps
-        coordLayRnd[as.numeric(turbInx),] <- cordNew
+        coordLayRnd[as.numeric(turbInx), ] <- cordNew
       }
     }
     if (Plot) {
       points(x = cordNew[1], y = cordNew[2], col = "green", pch = 20)
     }
     #####################
-    
+
     ## Arrange random points to input for calculate_energy
     coordLayRnd <- cbind(coordLayRnd,
-                         "ID" = 1,
-                         "bin" = 1)
+      "ID" = 1,
+      "bin" = 1
+    )
     coordLayRnd <- coordLayRnd[, c("ID", "X", "Y", "bin")]
-    
-    
+
+
     # Calculate energy and save in list with length n ################
-    resCalcen <- calculate_energy(sel = coordLayRnd,
-                                  referenceHeight = ref_height,
-                                  RotorHeight = rotor_height,
-                                  SurfaceRoughness = 0.3, wnkl = max_angle, distanz = max_dist,
-                                  dirSpeed = winddata,
-                                  RotorR = rotor_radius,
-                                  polygon1 = Polygon1, topograp = FALSE,
-                                  srtm_crop = NULL, cclRaster = NULL, weibull = FALSE)
-    
+    resCalcen <- calculate_energy(
+      sel = coordLayRnd,
+      referenceHeight = ref_height,
+      RotorHeight = rotor_height,
+      SurfaceRoughness = 0.3, wnkl = max_angle, distanz = max_dist,
+      dirSpeed = winddata,
+      RotorR = rotor_radius,
+      polygon1 = Polygon1, topograp = FALSE,
+      srtm_crop = NULL, cclRaster = NULL, weibull = FALSE
+    )
+
     ## Process Data ###################
     ee <- lapply(resCalcen, function(x) {
-      subset.matrix(x, subset = !duplicated(x[,'Punkt_id']),
-                    select = c('Bx','By','Windrichtung','RotorR','TotAbschProz','V_New',
-                               'Rect_ID','Energy_Output_Red', 'Energy_Output_Voll',
-                               'Parkwirkungsgrad'))
+      subset.matrix(x,
+        subset = !duplicated(x[, "Punkt_id"]),
+        select = c(
+          "Bx", "By", "Windrichtung", "RotorR", "TotAbschProz", "V_New",
+          "Rect_ID", "Energy_Output_Red", "Energy_Output_Voll",
+          "Parkwirkungsgrad"
+        )
+      )
     })
-    
+
     # get Energy Output and Efficiency rate for every wind direction
     enOut <- lapply(ee, function(x) {
       subset.matrix(x,
-                    subset = c(TRUE, rep(FALSE, length(ee[[1]][, 1]) - 1)),
-                    select = c('Windrichtung', 'Energy_Output_Red', 'Parkwirkungsgrad'))})
+        subset = c(TRUE, rep(FALSE, length(ee[[1]][, 1]) - 1)),
+        select = c("Windrichtung", "Energy_Output_Red", "Parkwirkungsgrad")
+      )
+    })
     enOut <- do.call("rbind", enOut)
-    
+
     # Add the Probability of every direction
     # Calculate the relative Energy outputs respective to the probability of the wind direction
-    enOut <- cbind(enOut, 'probabDir' = probabDir)
-    enOut <- cbind(enOut, 'Eneralldire' = enOut[,'Energy_Output_Red'] * (enOut[,'probabDir'] / 100))
-    
+    enOut <- cbind(enOut, "probabDir" = probabDir)
+    enOut <- cbind(enOut, "Eneralldire" = enOut[, "Energy_Output_Red"] * (enOut[, "probabDir"] / 100))
+
     # Calculate the sum of the relative Energy outputs
-    enOut <- cbind(enOut, 'EnergyOverall' = sum(enOut[,'Eneralldire']))
-    
-    # Calculate the sum of the relative Efficiency rates respective to the probability of the 
+    enOut <- cbind(enOut, "EnergyOverall" = sum(enOut[, "Eneralldire"]))
+
+    # Calculate the sum of the relative Efficiency rates respective to the probability of the
     # wind direction
-    enOut <- cbind(enOut, 'Efficalldire' = sum(enOut[,'Parkwirkungsgrad'] * (enOut[,'probabDir'] / 100)))
-    
+    enOut <- cbind(enOut, "Efficalldire" = sum(enOut[, "Parkwirkungsgrad"] * (enOut[, "probabDir"] / 100)))
+
     # Get the total Wake Effect of every Turbine for all Wind directions
-    AbschGesamt <- lapply(ee, function(x){ 
-      x[,'TotAbschProz']
+    AbschGesamt <- lapply(ee, function(x) {
+      x[, "TotAbschProz"]
     })
     AbschGesamt <- do.call("cbind", AbschGesamt)
     AbschGesamt <- rowSums(AbschGesamt)
-    
+
     # Get the original X / Y - Coordinates of the selected individual
     xundyOrig <- coordLayRnd[, 2:3]
-    
-    # Add the Efficieny and the Energy Output of all wind directions and add the total 
+
+    # Add the Efficieny and the Energy Output of all wind directions and add the total
     # Wake Effect of every Point Location
     # Include the Run of the genertion to the data frame
     xundyOrig <- cbind(xundyOrig,
-                       'EfficAllDir' = enOut[1, 'Efficalldire'],
-                       'EnergyOverall' = enOut[1, 'EnergyOverall'],
-                       'AbschGesamt' = AbschGesamt,
-                       'Run' = i)
-    
-    
+      "EfficAllDir" = enOut[1, "Efficalldire"],
+      "EnergyOverall" = enOut[1, "EnergyOverall"],
+      "AbschGesamt" = AbschGesamt,
+      "Run" = i
+    )
+
+
     # Get the Rotor Radius and the Rect_IDs of the park configuration
-    dt <-  ee[[1]]
+    dt <- ee[[1]]
     # layout_start
-    dt <- subset.matrix(dt, select = c('RotorR', 'Rect_ID'))
-    
+    dt <- subset.matrix(dt, select = c("RotorR", "Rect_ID"))
+
     # Bind the Efficiency,Energy,WakeEffect,Run to the Radius and Rect_IDs
     dt <- cbind(xundyOrig,
-                dt,
-                "bestGARun" = bestGARun)
+      dt,
+      "bestGARun" = bestGARun
+    )
     RandResult[[i]] <- dt
   }
   return(RandResult)
