@@ -9,22 +9,21 @@
 #'
 #' @family Helper Functions
 #' @return Returns the selected crossover method (character)
-#' @examples \dontrun{
-#'   readinteger()
-#' }
-#'
-readinteger <- function(){
-  cat("\nSelect appropriate Method. Either 'EQU' for equal crossover parts or 'RAN' for random parts.\n")
-  # crPaInter <- readline(prompt = "Type 'R' for random and 'E' for equal parts.")
-  cat("Type 'R' for random and 'E' for equal parts.\n")
+readinteger <- function() {
+  message("Select appropriate Method. Either 'EQU' for equal crossover parts or 'RAN' for random parts.\n")
+  message("Type 'R' for random and 'E' for equal parts.\n")
   crPaInter <- readLines(n = 1, con = getOption("windfarmGA.connection"))
-  
+
   crPaInter <- toupper(crPaInter)
 
-  if (crPaInter == "R") {crossPart <- "RAN"}
-  if (crPaInter == "E") {crossPart <- "EQU"}
+  if (crPaInter == "R") {
+    crossPart <- "RAN"
+  }
+  if (crPaInter == "E") {
+    crossPart <- "EQU"
+  }
 
-  if  (crPaInter != "E" & crPaInter != "R") {
+  if (crPaInter != "E" && crPaInter != "R") {
     crossPart <- readinteger()
   }
 
@@ -41,25 +40,23 @@ readinteger <- function(){
 #'
 #' @family Helper Functions
 #' @return Returns the selected selection method (character)
-#' @examples \dontrun{
-#'   readintegerSel()
-#' }
-readintegerSel <- function(){
-  cat("\nSelect appropriate Selection Method. Either 'FIX' or 'VAR' are available.\n")
-  # selstaPr <- readline(prompt = "Type 'F' for a fixed percentage of 50% and 'V' for a variable percentage.")
-  
-  cat("Type 'F' for a fixed percentage of 50% and 'V' for a variable percentage.\n")
+readintegerSel <- function() {
+  message("Select appropriate Selection Method. Either 'FIX' or 'VAR' are available.\n")
+
+  message("Type 'F' for a fixed percentage of 50% and 'V' for a variable percentage.\n")
   selstaPr <- readLines(n = 1, con = getOption("windfarmGA.connection"))
-  
+
   selstaPr <- toupper(selstaPr)
-  if (selstaPr == "F") {selstate <- "FIX"}
-  if (selstaPr == "V") {selstate <- "VAR"}
-  
-  if  (selstaPr != "F" & selstaPr != "V") {
+  if (selstaPr == "F") {
+    selstate <- "FIX"
+  }
+  if (selstaPr == "V") {
+    selstate <- "VAR"
+  }
+
+  if (selstaPr != "F" && selstaPr != "V") {
     selstate <- readintegerSel()
   }
   return(selstate)
 }
 # nocov end
-
-
